﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Data;

namespace GridTest5
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : INotifyPropertyChanged
	{
		private MyList _selectedList;
		public static MainWindow Instance { get; private set; }

		public MainWindow()
		{
			InitializeComponent();
			DataContext = this;
			Instance = this;

			Lists = new List<MyList>
			{
				new MyList("corp", 10),
				new MyList("users", 7),
				new MyList("test", 20),
			};

			SelectedList = Lists[0];
		}

		public List<MyList> Lists { get; set; }
		public MyList SelectedList
		{
			get { return _selectedList; }
			set { _selectedList = value; NotifyPropertyChanged("SelectedList"); }
		}

		public event PropertyChangedEventHandler PropertyChanged;
		public void NotifyPropertyChanged(string property)
		{
			var handler = PropertyChanged;
			if (handler != null) handler(this, new PropertyChangedEventArgs(property));
		}
	}

	public class MyList
	{
		public MyList(string prefix, int count)
		{
			Items = new ObservableCollection<Record>();
			for (var idx = 1; idx <= count; idx++)
			{
				var curr = new Record
				{
					Name = prefix + " user " + idx,
					Email = "mail" + (idx * 10) + "@" + prefix + ".com",
					Date = DateTime.Now.AddMinutes(idx)
				};
				Items.Add(curr);
			}

			FilteredItems = new ListCollectionView(Items);
            FilteredItems.CurrentChanged += new EventHandler(FilteredItems_CurrentChanged);
			FilteredItems.SortDescriptions.Add(new SortDescription("Name", ListSortDirection.Ascending));

			Name = prefix.ToUpper();
		}

        void FilteredItems_CurrentChanged(object sender, EventArgs e)
        {
            FilteredItems.SortDescriptions.Add(new SortDescription("Name", ListSortDirection.Ascending));            
        }

		public string Name { get; set; }
		public ObservableCollection<Record> Items { get; set; }
		public ListCollectionView FilteredItems { get; set; }
	}

	public class Record
	{
		public string Name { get; set; }
		public string Email { get; set; }
		public DateTime Date { get; set; }
	}
}
